@@ -1,24 +1,23 @@
 /*
  * File: lib.rs
  * Project: src
- * Created Date: 26/05/2021
+ * Created Date: 27/04/2022
  * Author: Shun Suzuki
  * -----
- * Last Modified: 30/05/2021
+ * Last Modified: 05/05/2022
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
- * Copyright (c) 2021 Hapis Lab. All rights reserved.
+ * Copyright (c) 2022 Hapis Lab. All rights reserved.
  *
  */
 
 mod controller;
 mod error;
-/// primitive gains
 pub mod gain;
-/// primitive modulations
 pub mod modulation;
 pub mod prelude;
-mod stm_controller;
+mod silencer_config;
 
+pub use autd3_core;
 pub use controller::Controller;
-pub use stm_controller::{StmController, StmTimer};
+pub use silencer_config::SilencerConfig;
