@@ -1,20 +1,20 @@
 /*
  * File: mod.rs
  * Project: modulation
- * Created Date: 27/05/2021
+ * Created Date: 28/04/2022
  * Author: Shun Suzuki
  * -----
- * Last Modified: 28/07/2021
+ * Last Modified: 05/05/2022
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
- * Copyright (c) 2021 Hapis Lab. All rights reserved.
+ * Copyright (c) 2022 Hapis Lab. All rights reserved.
  *
  */
 
-mod sine;
-mod sine_legacy;
-mod sine_pressure;
-mod r#static;
+pub mod sine;
+pub mod sine_legacy;
+pub mod sine_pressure;
+pub mod r#static;
 
 pub use r#static::Static;
 pub use sine::Sine;
