@@ -1,34 +1,31 @@
 /*
  * File: sine_pressure.rs
  * Project: modulation
- * Created Date: 05/06/2021
+ * Created Date: 05/05/2022
  * Author: Shun Suzuki
  * -----
- * Last Modified: 14/10/2021
+ * Last Modified: 05/05/2022
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
- * Copyright (c) 2021 Hapis Lab. All rights reserved.
+ * Copyright (c) 2022 Hapis Lab. All rights reserved.
  *
  */
 
 use std::f64::consts::PI;
 
 use anyhow::Result;
-use autd3_core::{hardware_defined, modulation::Modulation};
+use autd3_core::modulation::{ModProps, Modulation};
 use autd3_traits::Modulation;
 
 use num::integer::gcd;
 
-/// Sine wave modulation in radiation pressure
+/// Sine wave modulation in ultrasound amplitude
 #[derive(Modulation)]
 pub struct SinePressure {
-    buffer: Vec<u8>,
-    sent: usize,
+    props: ModProps,
     freq: usize,
     amp: f64,
     offset: f64,
-    sampling_freq_div: usize,
-    built: bool,
 }
 
 impl SinePressure {
@@ -53,13 +50,10 @@ impl SinePressure {
     ///
     pub fn with_params(freq: usize, amp: f64, offset: f64) -> Self {
         Self {
-            buffer: vec![],
-            sent: 0,
+            props: ModProps::new(),
             freq,
             amp,
             offset,
-            sampling_freq_div: 10,
-            built: false,
         }
     }
 
@@ -74,14 +68,14 @@ impl SinePressure {
         let n = sf / d;
         let rep = freq / d;
 
-        self.buffer.resize(n, 0);
+        self.props.buffer.resize(n, 0);
 
-        for i in 0..n {
+        self.props.buffer.iter_mut().enumerate().for_each(|(i, m)| {
             let amp = self.amp / 2.0 * (2.0 * PI * (rep * i) as f64 / n as f64).sin() + self.offset;
             let amp = amp.sqrt().clamp(0.0, 1.0);
             let duty = amp.asin() * 2.0 / PI * 255.0;
-            self.buffer[i] = duty as u8;
-        }
+            *m = duty as u8
+        });
 
         Ok(())
     }
